![Recurso 6LogoSSPY](https://github.com/user-attachments/assets/129ae893-cfdc-45d1-9e67-8faf0e1169c5)
# PhotoprotectionPy
PhotoprotectionPy is a python package to perform the calculations needed to determine and evaluate *in vitro* Sunscreen Protection Factor (SPF) following ISO 24443.

Documentation, Tutorials and Wiki are available on [Link](https://github.com/santiagohigareda/photoprotectionpy). 

To cite PhotoprotectionPy, please use the following reference:
```
Guerrero-Higareda, S. (2025). PhotoprotectionPy (Version 1.0.2) [Python].
  https://github.com/santiagohigareda/photoprotectionpy
```

## License and copyright notice

© 2024 Santiago Guerrero-Higareda

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
```
  http://www.apache.org/licenses/LICENSE-2.0
```
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License
